@@ -168,6 +168,7 @@ use vars qw(
 	GL_CLIENT_ACTIVE_TEXTURE
 	GL_CLIENT_ACTIVE_TEXTURE_ARB
 	GL_CLIENT_ALL_ATTRIB_BITS
+	GL_ALL_CLIENT_ATTRIB_BITS
 	GL_CLIENT_ATTRIB_STACK_DEPTH
 	GL_CLIENT_PIXEL_STORE_BIT
 	GL_CLIENT_VERTEX_ARRAY_BIT
@@ -1735,6 +1736,7 @@ sub GL_CLEAR {0x1500}
 sub GL_CLIENT_ACTIVE_TEXTURE {0x84E1}
 sub GL_CLIENT_ACTIVE_TEXTURE_ARB {0x84E1}
 sub GL_CLIENT_ALL_ATTRIB_BITS {0xFFFFFFFF}
+sub GL_ALL_CLIENT_ATTRIB_BITS {0xFFFFFFFF}
 sub GL_CLIENT_ATTRIB_STACK_DEPTH {0x0BB1}
 sub GL_CLIENT_PIXEL_STORE_BIT {0x00000001}
 sub GL_CLIENT_VERTEX_ARRAY_BIT {0x00000002}
